mdast2minimad
This crate has the objective to export the largest possible subset of mdast from the crate markdown to the ast exposed by the crate minimad.
The main use of this crate is in dices, where the ast is edited to render the code example before using termimand to print them.
Limitations
minimad parser is not a fully fledget markdown parser. This make the two ASTs impossble to transpose: for example this two snippets of markdown represent the same document, but are parsed differently by minimad:
This is a paragraph.
This is another.This is a paragraph.
This is another.The translation is then made on a best effort base.
License
This software is distributed under the MIT license, if you need to know. Use it at will.
Contacts
This library was made by zannabianca1997. If you found any problem with the library itself, or want to contribute, you can send a PR, or contact me at zannabianca199712@gmail.com.
Modules
Structs
Enums
- ToMinimad
Error - General error happening while converting the AST into a
minimadtext
Functions
- md_
parse_ options - Return the
markdown::ParseOptionscontaining all the constructs supported by the conversion - to_
custom_ minimad - Convert the markdown AST to a minimad Text, with custom options.
- to_
minimad - Convert the markdown AST to a minimad Text